SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
Этот коммит содержится в:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
коммит произвёл GitHub
родитель f6f8a0d144
Коммит e6ded45898
14 изменённых файлов: 47 добавлений и 47 удалений
+1 -1
Просмотреть файл
@@ -43,7 +43,7 @@ void matrixRowSum(int* input, int* output, int width) {
// Device (kernel) function
__global__ void gpuMatrixRowSum(int* input, int* output, int width) {
int index = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int index = blockDim.x * blockIdx.x + threadIdx.x;
#pragma unroll
for (int i = 0; i < width; i++) {
output[index] += input[index * width + i];